@@ -14,28 +14,40 @@ try:
     import ConfigParser
 except:
     import configparser as ConfigParser
-cf = ConfigParser.ConfigParser()
+
 
 DEFAULT='DEFAULT'
 
 def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None, nodes=None,
            force=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
-           file=None, priority=None,  show_json=False):
+           file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None, show_json=False):
 
-    if cmd == None and file == None:
+    if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
         print('\n  type "%s sub -h" for more\n' % CMD)
         return
 
-    job_desc = trans_file_to_job_desc(file)
+    # compatible timeout
+    if str.isdigit(type or ''):
+        timeout = int(type)
+        type = None
+
+    job_desc = trans_file_to_job_desc(file, not show_json)
 
     opt = {
         'cmd': cmd,
         'job_name': job_name,
         'description': description,
         'cluster': cluster,
+        'disk': disk,
+        'user_data': user_data,
         'timeout': timeout,
         'nodes' : nodes,
         'force': force,
+        'lock': lock,
+        'locale': locale,
+
+        'image': image,
+        'type': type,
 
         'priority': priority,
 
@@ -48,7 +60,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'mount': mount
     }
 
-    job_desc = fix_by_opt(job_desc, opt)
+    job_desc = fix_by_opt(job_desc, opt, not show_json)
 
     deal_with_pack(job_desc, show_json)
 
@@ -112,7 +124,7 @@ def pack_upload(pack, package_path):
             print('packing a single file..')
             build_tar_from_arr_and_upload([pack],package_path)
 
-def fix_by_opt(desc, opt):
+def fix_by_opt(desc, opt, check_cluster):
 
     if opt.get('job_name'):
         desc['Name'] = opt['job_name']
@@ -125,17 +137,39 @@ def fix_by_opt(desc, opt):
 
 
 
+
     tasks = desc['DAG']['Tasks']
     for (task_name,task_desc) in tasks.items():
 
         if opt.get('cmd'):
             task_desc['Parameters']['Command']['CommandLine']=opt['cmd']
+
+        if not task_desc['Parameters']['Command'].get('CommandLine'):
+            raise Exception('Missing required option: cmd')
+
+
         if opt.get('timeout'):
             task_desc['Timeout'] = trans_timeout(opt['timeout'])
         if opt.get('nodes'):
             task_desc['InstanceCount'] = trans_nodes(opt['nodes'])
         if opt.get('cluster'):
-            extend(task_desc, trans_cluster(opt['cluster']))
+            extend(task_desc, trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster))
+        else:
+            if opt.get('image'):
+                task_desc['AutoCluster']['ImageId'] = opt.get('image')
+            if opt.get('type'):
+                task_desc['AutoCluster']['InstanceType'] = opt.get('type')
+
+
+
+        if opt.get('user_data'):
+            user_data_m = trans_user_data(opt['user_data'])
+            if not task_desc['AutoCluster'].get('UserData'):
+                task_desc['AutoCluster']['UserData'] = {}
+            extend(task_desc['AutoCluster']['UserData'], user_data_m)
+
+        if opt.get('disk') and task_desc.get('AutoCluster'):
+            task_desc['AutoCluster']['Configs'] = {'Disks': opt['disk']}
 
         if opt.get('docker'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(opt['docker']))
@@ -150,6 +184,11 @@ def fix_by_opt(desc, opt):
         if opt.get('write_mount'):
             extend(task_desc['OutputMapping'], reverse_kv(trans_mount(opt['write_mount'])))
 
+        if opt.get('lock'):
+            task_desc['Parameters']['InputMappingConfig']['Lock'] = opt['lock']
+        if opt.get('locale'):
+            task_desc['Parameters']['InputMappingConfig']['Locale'] = opt['locale']
+
         # cache
         if opt.get('pack'):
             task_desc['pack'] = opt['pack']
@@ -160,8 +199,8 @@ def fix_by_opt(desc, opt):
 
 ########################################
 
-def trans_file_to_job_desc(file):
-
+def trans_file_to_job_desc(file, check_cluster):
+    cf = ConfigParser.ConfigParser()
     # parse file
     if not file:
         desc = gen_job_desc()
@@ -230,6 +269,12 @@ def trans_file_to_job_desc(file):
             if cf.has_option(DEFAULT,'write_mount'):
                 w_mount_m = trans_mount(cf.get(DEFAULT,'write_mount'))
                 extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
+
+            if cf.has_option(DEFAULT, 'user_data'):
+                user_data_m = trans_user_data(cf.get(DEFAULT, 'user_data'))
+                if not task_desc['AutoCluster'].get('UserData'):
+                    task_desc['AutoCluster']['UserData'] = {}
+                extend(task_desc['AutoCluster']['UserData'], user_data_m)
             ###################################
 
 
@@ -237,8 +282,8 @@ def trans_file_to_job_desc(file):
 
         if cf.has_option(sec, "cmd"):
             task_desc['Parameters']['Command']['CommandLine']= cf.get(sec,'cmd')
-        else:
-            raise Exception('Missing required option: cmd')
+        # else:
+        #     raise Exception('Missing required option: cmd')
 
 
         # cache
@@ -253,8 +298,22 @@ def trans_file_to_job_desc(file):
             task_desc['InstanceCount']=trans_nodes(cf.getint(sec,'nodes'))
 
         if cf.has_option(sec,'cluster'):
-            extend(task_desc, trans_cluster(cf.get(sec,'cluster')) )
+            img = cf.get(sec, 'image') if cf.has_option(sec,'image') else None
+            tp = cf.get(sec, 'type') if cf.has_option(sec,'type') else None
+            extend(task_desc, trans_cluster(cf.get(sec,'cluster'), img , tp, check_cluster) )
+        else:
+            if cf.has_option(sec,'image'):
+                task_desc['AutoCluster']['ImageId']=cf.get(sec,'image')
+            if cf.has_option(sec, 'type'):
+                task_desc['AutoCluster']['InstanceType'] = cf.get(sec, 'type')
 
+        if cf.has_option(sec, 'disk') and task_desc.get('AutoCluster'):
+            task_desc['AutoCluster']['Configs'] = {'Disks': trans_disk(cf.get(sec, 'disk')) }
+
+        if cf.has_option(sec, 'user_data'):
+            if not task_desc['AutoCluster']['UserData']:
+                task_desc['AutoCluster']['UserData'] = {}
+            extend(task_desc['AutoCluster']['UserData'] ,trans_user_data(cf.get(sec, 'user_data')))
 
         if cf.has_option(sec,'env'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_env(cf.get(sec,'env')))
@@ -272,6 +331,11 @@ def trans_file_to_job_desc(file):
             w_mount_m = trans_mount(cf.get(sec,'write_mount'))
             extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
 
+        if cf.has_option(sec,'lock'):
+            task_desc['Parameters']['InputMappingConfig']['Lock'] = cf.get('lock')
+        if cf.has_option(sec,'locale'):
+            task_desc['Parameters']['InputMappingConfig']['Locale'] = cf.get('locale')
+
         desc['DAG']['Tasks'][sec]= task_desc
 
     return desc
@@ -294,8 +358,17 @@ def trans_deps(deps):
         m[k] = [x.strip() for x in v.split(',')]
     return m
 
-def trans_cluster(cluster):
-    return util.parse_cluster_cfg(cluster)
+def trans_cluster(cluster, image=None, type=None, check_cluster=True):
+    obj = util.parse_cluster_cfg(cluster, check_cluster)
+
+    if obj['ClusterId']=='':
+        if image:
+           obj['AutoCluster']['ImageId'] = image
+        if type:
+            obj['AutoCluster']['InstanceType'] = type
+
+    return obj
+
 
 def override_opt(opt, file):
     # asd
@@ -344,6 +417,17 @@ def trans_priority(p=None):
     except:
         return 1
 
+def trans_disk(disk):
+    return util.trans_disk(disk)
+
+
+def trans_user_data(user_data):
+    items = user_data.split(',')
+    m = {}
+    for item in items:
+        arr = item.split(':',1)
+        m[arr[0]]= arr[1] if len(arr)==2 else ''
+    return m
 
 #######################################
 
