@@ -157,6 +157,10 @@ def getJSON():
                 'pack': "optional,pack the files in the program_folder into worker.tar.gz, and upload to oss, if you don't set this option, no pack, no upload",
                 'priority': 'optional,int,job priority,default:0\n',
                 'timeout': "optional,job would failed if it had expired, default: 172800(2 days)",
+                'image': """optional, set autoCluster image id, priority is higher than auto_cluster string set by cluster option,
+                                      and it doesn't work when clusterId is set by cluster option""",
+                'type': """optional, set autoCluster instance type, priority is higher than auto_cluster string set by cluster option,
+                                      and it doesn't work when clusterId is set by cluster option""",
                 'nodes': "optional,the number of machines you needed to run the program, default: 1",
                 'description': 'optional,set job description',
                 'force': "optional,job don't fail when instance were failed, default: job fail when even one instance were failed",
