@@ -174,6 +174,8 @@ def __get_json():
                 'pack': "可选,打包指定目录下的文件,并上传到OSS, 如果没有指定这个选项则不打包不上传",
                 'priority': '可选,int类型,指定作业优先级,默认:0\n',
                 'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 172800(单位秒,表示2天)",
+                'image': "可选, AutoCluster使用的imageId, 优先级高于cluster中的AutoCluster字符串配置, 设置cluster为clusterId时该项无效",
+                'type': "可选, AutoCluster使用的instanceType, 优先级高于cluster中的AutoCluster字符串配置, 设置cluster为clusterId时该项无效",
                 'nodes': "可选,需要运行程序的机器数, 默认: 1",
                 'description': '可选,设置作业描述',
                 'force': "可选,当instance失败时job不失败, 默认:当instance失败时job也失败",
