@@ -52,7 +52,7 @@ def get_cluster_str(task_desc):
         return "img=%s:type=%s" % (task_desc['AutoCluster']['ECSImageId'] or task_desc['AutoCluster']['ImageId'], task_desc['AutoCluster']['InstanceType'])
 
 
-def parse_cluster_cfg(s=None):
+def parse_cluster_cfg(s=None, checkCluster=True):
     if not s:
         return {
             'AutoCluster':{
@@ -93,15 +93,17 @@ def parse_cluster_cfg(s=None):
         #print(white('using AuthCluster: %s' % m))
         return {'AutoCluster':m,'ClusterId':''}
     else:
-        result = client.list_clusters()
-        clusters = result.get('Items')
-        for c in clusters:
-            if c.get('Id')==s:
-                #print(white('using Cluster: %s' % s))
-                return {'ClusterId':s,'AutoCluster':{}}
-
-        raise Exception('Invalid ClusterId, type "%s c" for more' % CMD)
+        if checkCluster:
+            result = client.list_clusters()
+            clusters = result.get('Items')
+            for c in clusters:
+                if c.get('Id')==s:
+                    #print(white('using Cluster: %s' % s))
+                    return {'ClusterId':s,'AutoCluster':{}}
 
+            raise Exception('Invalid ClusterId, type "%s c" for more' % CMD)
+        else:
+            return {'ClusterId': s, 'AutoCluster': {}}
 
 
 def trans_mount(s):
@@ -202,3 +204,26 @@ def trans_disk(disk):
         raise Exception(
             'Invalid disk format, it should like this: --disk system:ephemeral:40,data:cloud:500:/home/disk, append -h for more')
 
+
+
+def set_default_type_n_image():
+    # if not found default type
+    # or not a available type
+    m = config.getConfigs(config.COMMON)
+    default_type = m.get('defaulttype')
+    arr = client.list_instance_types()
+
+    if default_type:
+        for n in arr:
+            if default_type==n['name']:
+                return
+
+    m['defaulttype']=arr[0]['name']
+
+    # if not found default image
+    default_image = m.get('defaultimage')
+    if not default_image:
+        m['defaultimage']='img-ubuntu'
+
+    config.setConfigs(config.COMMON, m)
+
